Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(756)

Unified Diff: Source/core/dom/shadow/ShadowRoot.cpp

Issue 26900006: Rename Node::willBeDeletedFrom() to willBeDeletedFromDocument() (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Take comments into consideration Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/dom/Node.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/dom/shadow/ShadowRoot.cpp
diff --git a/Source/core/dom/shadow/ShadowRoot.cpp b/Source/core/dom/shadow/ShadowRoot.cpp
index da72c0ceb323c0e48685d1586a5b49d0945360d6..61e9671462c90d63f7a21fda4ba1f83eee318ab5 100644
--- a/Source/core/dom/shadow/ShadowRoot.cpp
+++ b/Source/core/dom/shadow/ShadowRoot.cpp
@@ -87,11 +87,11 @@ ShadowRoot::~ShadowRoot()
documentInternal()->styleEngine()->didRemoveShadowRoot(this);
// We cannot let ContainerNode destructor call willBeDeletedFrom()
// for this ShadowRoot instance because TreeScope destructor
// clears Node::m_treeScope thus ContainerNode is no longer able
// to access it Document reference after that.
- willBeDeletedFrom(documentInternal());
+ willBeDeletedFromDocument();
// We must remove all of our children first before the TreeScope destructor
// runs so we don't go through TreeScopeAdopter for each child with a
« no previous file with comments | « Source/core/dom/Node.cpp ('k') | no next file » | no next file with comments »
@@ -87,11 +87,11 @@ ShadowRoot::~ShadowRoot()
documentInternal()->styleEngine()->didRemoveShadowRoot(this);
- // We cannot let ContainerNode destructor call willBeDeletedFrom()
+ // We cannot let ContainerNode destructor call willBeDeletedFromDocument()
// for this ShadowRoot instance because TreeScope destructor
// clears Node::m_treeScope thus ContainerNode is no longer able

Powered by Google App Engine
This is Rietveld 408576698